@@ -6,6 +6,7 @@ from gantry.logger.main import _init as logger_init
 from gantry.logger.main import (
     get_client,
     log_file,
+    log_from_data_connector,
     log_record,
     log_records,
     ping,
@@ -18,9 +19,10 @@ from gantry.utils import compute_feedback_id
 
 __all__ = [
     "init",
+    "log_file",
+    "log_from_data_connector",
     "log_record",
     "log_records",
-    "log_file",
     "ping",
     "ready",
     "get_client",
