@@ -4,6 +4,7 @@ import click
 
 from gantry.cli.application import application
 from gantry.cli.bucket import bucket
+from gantry.cli.data_connector import data_connector
 from gantry.cli.projection import projection
 from gantry.cli.secret import secret
 
@@ -36,6 +37,7 @@ def cli(ctx, loglevel):
 cli.add_command(projection)
 cli.add_command(application)
 cli.add_command(bucket)
+cli.add_command(data_connector)
 cli.add_command(secret)
 
 if __name__ == "__main__":
