@@ -1,5 +1,7 @@
+import datetime
 import io
 import logging
+from typing import Dict, List, Union
 
 import mock
 import numpy as np
@@ -9,9 +11,19 @@ from freezegun import freeze_time
 
 from gantry.exceptions import GantryLoggingException
 from gantry.logger import client
-from gantry.logger.constants import BatchType, UploadFileType
+from gantry.logger.constants import (
+    BatchType,
+    ScheduleFrequency,
+    ScheduleType,
+    UploadFileType,
+)
 from gantry.logger.stores import BaseLogStore
-from gantry.logger.types import DataLink
+from gantry.logger.types import (
+    DataLink,
+    IngestFromDataConnectorRequest,
+    Schedule,
+    ScheduleOptions,
+)
 
 from .conftest import (
     ANOTHER_TIME,
@@ -2019,3 +2031,140 @@ def test_log_records_size_match(
         )
         is not None
     )
+
+
+@pytest.mark.parametrize(
+    ("timestamp", "inputs", "outputs", "feedbacks", "join_key", "global_tags", "row_tags"),
+    [  # Test all combinations of inputs, outputs, feedbacks, and join_key
+        ("T", ["A", "B"], ["C", "D"], ["H", "I"], "E", {"version": "test_version"}, ["G"]),
+        # Test without feedbacks and row_tags
+        ("T", ["A", "B"], ["D"], None, "E", {"version": "test_version"}, None),
+        # Test without inputs and timestamp
+        (None, None, None, ["H", "I"], "E", {"version": "test_version"}, ["G"]),
+        # Test only with feedbacks and join_key
+        (None, None, None, ["H", "I"], "E", None, None),
+        # Test only with inputs and global tags
+        ("T", ["A", "B"], ["C", "D"], None, None, {"version": "test_version"}, None),
+    ],
+)
+def test_log_from_data_connector(
+    timestamp: str,
+    inputs: List[str],
+    outputs: List[str],
+    feedbacks: List[str],
+    join_key: str,
+    row_tags: List[str],
+    global_tags: Dict[str, str],
+    cli_obj,
+):
+    """
+    Tests that the log_from_data_connector function calls the log_from_data_connector_async
+    function with correct parameters
+    """
+    cli_obj.log_store = mock.Mock()
+    cli_obj.log_from_data_connector(
+        application="foobar",
+        source_data_connector_name="test-connector",
+        timestamp=timestamp,
+        inputs=inputs,
+        outputs=outputs,
+        feedbacks=feedbacks,
+        join_key=join_key,
+        row_tags=row_tags,
+        global_tags=global_tags,
+    )
+
+    call_args = cli_obj.log_store.log_from_data_connector_async.call_args
+    assert call_args.kwargs == {
+        "request": IngestFromDataConnectorRequest(
+            application="foobar",
+            source_data_connector_name="test-connector",
+            timestamp=timestamp,
+            inputs=inputs,
+            outputs=outputs,
+            feedbacks=feedbacks,
+            join_key=join_key,
+            row_tags=row_tags,
+            global_tags=global_tags,
+            schedule=None,
+            pipeline_name=None,
+        )
+    }
+
+
+@pytest.mark.parametrize(
+    ("start_on", "frequency", "type", "options"),
+    [
+        (
+            "2023-02-01T00:00:00.000000",
+            ScheduleFrequency.EVERY_HOUR,
+            ScheduleType.INCREMENTAL_APPEND,
+            {"watermark_key": "updated_at"},
+        ),
+        (
+            datetime.datetime.utcnow(),
+            ScheduleFrequency.EVERY_2_HOURS,
+            ScheduleType.INCREMENTAL_APPEND,
+            {"watermark_key": "updated_at"},
+        ),
+        (
+            datetime.datetime.utcnow(),
+            ScheduleFrequency.EVERY_4_HOURS,
+            ScheduleType.INCREMENTAL_APPEND,
+            {"watermark_key": "updated_at"},
+        ),
+    ],
+)
+def test_log_from_data_connector_with_schedule(
+    start_on: Union[datetime.datetime, str],
+    frequency: ScheduleFrequency,
+    type: ScheduleType,
+    options: Dict[str, str],
+    cli_obj,
+):
+    """
+    Tests that the log_from_data_connector function calls the log_from_data_connector_async
+    function with correct parameters
+    """
+    cli_obj.log_store = mock.Mock()
+    cli_obj.log_from_data_connector(
+        application="foobar",
+        source_data_connector_name="test-connector",
+        timestamp="T",
+        inputs=["A", "B"],
+        outputs=["C", "D"],
+        feedbacks=["E", "F"],
+        join_key="H",
+        row_tags=["I", "J"],
+        global_tags={"version": "test_version"},
+        schedule=Schedule(
+            start_on=start_on,
+            frequency=frequency,
+            type=type,
+            options=ScheduleOptions(**options),
+        ),
+    )
+
+    call_args = cli_obj.log_store.log_from_data_connector_async.call_args
+    assert call_args.kwargs == {
+        "request": IngestFromDataConnectorRequest(
+            application="foobar",
+            source_data_connector_name="test-connector",
+            timestamp="T",
+            inputs=["A", "B"],
+            outputs=["C", "D"],
+            feedbacks=["E", "F"],
+            join_key="H",
+            row_tags=["I", "J"],
+            global_tags={"version": "test_version"},
+            schedule=Schedule(
+                start_on=start_on.isoformat()
+                if isinstance(start_on, datetime.datetime)
+                else start_on,
+                frequency=frequency,
+                type=type,
+                options=ScheduleOptions(**options),
+            ),
+            pipeline_name=None,
+        )
+    }
